@@ -1,6 +1,6 @@
 package XML::MyXML;
 {
-  $XML::MyXML::VERSION = '0.9001';
+  $XML::MyXML::VERSION = '0.9002';
 }
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
 
@@ -480,7 +480,7 @@ sub check_xml {
 
 package XML::MyXML::Object;
 {
-  $XML::MyXML::Object::VERSION = '0.9001';
+  $XML::MyXML::Object::VERSION = '0.9002';
 }
 
 use Carp;
@@ -698,7 +698,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9001
+version 0.9002
 
 =head1 SYNOPSIS
 
@@ -714,9 +714,9 @@ version 0.9001
     $obj->simplify is hashref { item => { name => 'Table', price => { usd => '10.00', eur => '8.50' } } }
     $obj->simplify({ internal => 1 }) is hashref { name => 'Table', price => { usd => '10.00', eur => '8.50' } }
 
-=head1 EXPORT
+=head1 EXPORTABLE
 
-tidy_xml, xml_to_object, object_to_xml, simple_to_xml, xml_to_simple, check_xml
+xml_escape, tidy_xml, xml_to_object, object_to_xml, simple_to_xml, xml_to_simple, check_xml
 
 =head1 FEATURES & LIMITATIONS
 
@@ -810,6 +810,43 @@ Optional flags: C<file>
 
 Returns the element specified by the path as an XML::MyXML::Object object. When there are more than one tags with the specified name in the last step of the path, it will return all of them as an array. In scalar context will only return the first one. CSS3-style attribute selectors are allowed in the path next to the tagnames, for example: C<< p[class=big] >> will only return C<< <p> >> elements that contain an attribute called "class" with a value of "big". p[class] on the other hand will return p elements having a "class" attribute, but that attribute can have any value.
 
+An example... To print the last names of all the students from the following XML, do:
+
+    my $xml = <<'EOB';
+    <people>
+        <student>
+            <name>
+                <first>Alex</first>
+                <last>Karelas</last>
+            </name>
+        </student>
+        <student>
+            <name>
+                <first>John</first>
+                <last>Doe</last>
+            </name>
+        </student>
+        <teacher>
+            <name>
+                <first>Mary</first>
+                <last>Poppins</last>
+            </name>
+        </teacher>
+        <teacher>
+            <name>
+                <first>Peter</first>
+                <last>Gabriel</last>
+            </name>
+        </teacher>
+    </people>
+    EOB
+    
+    my $obj = xml_to_object($xml);
+    my @students = $obj->path('student');
+    foreach my $student (@students) {
+        print $student->path('name/last')->value, "\n";
+    }
+
 =head2 $obj->value
 
 When the element represented by the $obj object has only text contents, returns those contents as a string. If the $obj element has no contents, value will return an empty string.
@@ -858,11 +895,11 @@ your bug as I make changes.
 
 =head1 AUTHOR
 
-Alexander Karelas <karjala@cpan.org>
+Alexander Karelas <karjala@karjala.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Alexander Karelas.
+This software is copyright (c) 2014 by Alexander Karelas.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
